from setuptools import setup, find_packages

setup(
    name='packaging_splitter',
    version='0.1',
    packages=find_packages(),
    author='Mubaraka Banadda',
    author_email='mubarakabanadda68@gmail.com',
    description='A package for splitting image datasets into train, test, and validation sets'
)
